api.cases.v1 package — Argus-Toolbelt 1.0 documentation

# api.cases.v1 package

## Submodules

## api.cases.v1.case module

Autogenerated API

`api.cases.v1.case.` `get_case_entries`(caseId: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List case entries (TEST)

  Return type: | `dict`
  Parameters: | caseId (int) – ID of case to list entries from
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 211, “limit”: 868, “responseCode”: 200, “count”: 359, “data”: [{“description”: “Go old education skin.”, “tags”: [{“value”: “Such military of difference.”}], “properties”: {“additionalProperties”: “More enough radio free so.”}, “flags”: 214, “userACL”: [883], “createdByUser”: {“id”: 233, “customerID”: 203, “userName”: “nunezkaren”, “name”: “Karen Beltran”}, “customerReference”: “Company song remember paper experience.”, “status”: “PENDING_SOC”, “priority”: 431, “text”: “Call be benefit get and add major read.”, “id”: 732, “createdTimestamp”: 183061393, “lastUpdatedTimestamp”: 765192701, “publishedTimestamp”: 589026921}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Foot me a tax use wind group some.”, “messageTemplate”: “Heart financial hour parent spring beyond parent student.”, “field”: “Offer inside oil fine hundred happen.”, “parameter”: {}, “timestamp”: 642191824}], “currentPage”: 274, “size”: 4}

`api.cases.v1.case.` `get_case_meta_data`(caseId: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch metadata for a customer case (TEST)

  Return type: | `dict`
  Parameters: | caseId (int) – Case ID
  Raises: | AuthenticationFailedException – on 401 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 903, “limit”: 599, “responseCode”: 200, “count”: 850, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Civil water physical food I law letter.”, “messageTemplate”: “Prevent rock field TV language.”, “field”: “Business another high scientist generation.”, “parameter”: {}, “timestamp”: 123646857}], “currentPage”: 476, “size”: 258}

`api.cases.v1.case.` `list_cases`(serviceTypeID: list = None, customerID: list = None, status: list = None, offset: int = None, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List customer logs (TEST)

  Return type: | `dict`
  Parameters: | serviceTypeID (list) – ID of service types to limit to customerID (list) – ID of customers to limit to status (list) – Status to limit to offset (int) – Offset result limit (int) – Limit result
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 240, “limit”: 306, “responseCode”: 200, “count”: 788, “data”: [{“description”: “Increase police trade little doctor.”, “tags”: [{“value”: “Special resource energy site down effort.”}], “properties”: {“additionalProperties”: “Lay similar would.”}, “flags”: 617, “userACL”: [357], “createdByUser”: {“id”: 289, “customerID”: 813, “userName”: “gcollins”, “name”: “Tammy Mitchell”}, “status”: “PENDING_CUSTOMER”, “logType”: “SECURITY_INCIDENT”, “customerReference”: “Can control establish feeling set.”, “priority”: 178, “contacts”: [{“id”: 4, “languageID”: 116, “name”: “Julia Martinez”, “value”: “Hot month military serious large.”, “flags”: 809, “subjectID”: 605, “verbose”: true, “language”: “NORWEGIAN”, “default”: true}], “id”: 493, “createdTimestamp”: 1514990411, “lastUpdatedTimestamp”: 130959408, “publishedTimestamp”: 927767123}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Detail turn bar executive short.”, “messageTemplate”: “Accept stand base type.”, “field”: “Against say half about improve.”, “parameter”: {}, “timestamp”: 631938288}], “currentPage”: 453, “size”: 291}

`api.cases.v1.case.` `merge_cases`(mergeIntoID: int, mergeFromID: int, priority: int = None, status: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Merge one case into another (TEST)

  Return type: | `dict`
  Parameters: | mergeIntoID (int) – ID of case to put into mergeFromID (int) – ID of case to merge (will disappear) priority (int) – Priority to set for merged case status (str) – Status to set for merged case
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 69, “limit”: 303, “responseCode”: 200, “count”: 837, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Project world another sometimes majority child.”, “messageTemplate”: “Model service well read Mr everything.”, “field”: “Fine probably but share many.”, “parameter”: {}, “timestamp”: 1463254128}], “currentPage”: 749, “size”: 23}

`api.cases.v1.case.` `search_cases`(limit: int = None, offset: int = None, includeFlags: int = None, excludeFlags: int = None, customerID: list = None, user: list = None, owner: list = None, customerDataID: list = None, searchString: str = None, serviceType: list = None, subCriteria: list = None, logType: list = None, logCategory: list = None, status: list = None, minPriority: int = None, maxPriority: int = None, priority: list = None, textSearchFeatures: list = None, customerOwnerID: list = None, techOwnerID: list = None, assetID: list = None, sortBy: list = None, startTimestamp: int = None, endTimestamp: int = None, tags: list = None, includeDeleted: bool = 'False', exclude: bool = 'False', includeCreatedTimestamp: bool = 'False', includeLastUpdatedTimestamp: bool = 'False', ownerAssigned: bool = 'False', techAssigned: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Search for customer logs by criteria (TEST)

  Return type: | `dict`
  Parameters: | limit (int) – Limit results offset (int) – Offset results includeFlags (int) – Search objects with these flags set excludeFlags (int) – Exclude objects with these flags set customerID (list) – Limit result to objects belonging to these customers user (list) – Set of user IDs, limit search to data created/updated by users with this ID owner (list) – Set of user IDs, limit search to cases owned by (solution engineer or customer owner) users with this ID customerDataID (list) – Set of specific data objects searchString (str) – Words to search for serviceType (list) – Limit result to objects with these service types subCriteria (list) – logType (list) – Log types logCategory (list) – ID of log categories status (list) – Case status minPriority (int) – Minimum log priority maxPriority (int) – Maximum log priority priority (list) – Set of specific priorities textSearchFeatures (list) – Text search features customerOwnerID (list) – Set of user IDs, limit search to cases owned by (customer owner) users with this ID techOwnerID (list) – Set of user IDs, limit search to cases owned by (solution engineer) users with this ID assetID (list) – Set of asset IDs, limit search to cases associated with specified assets (hosts, services or processes) sortBy (list) – Order results by these properties (prefix with - to sort descending) startTimestamp (int) – Search objects from this timestamp endTimestamp (int) – Search objects until this timestamp tags (list) – Set of tags to search for (specify as key/value) includeDeleted (bool) – Also include deleted objects (where implemented) exclude (bool) – Exclude these criteria from parent criteria includeCreatedTimestamp (bool) – Include created timestamp when searching time period includeLastUpdatedTimestamp (bool) – Include last updated timestamp when searching time period ownerAssigned (bool) – If set to true, limit to cases where customer owner is assigned, false to limit to cases with no owner assigned. Default is no limitation. techAssigned (bool) – If set to true, limit to cases where solution engineer is assigned, false to limit to cases with no solution engineer assigned. Default is no limitation.
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 307, “limit”: 909, “responseCode”: 200, “count”: 140, “data”: [{“description”: “Ever play himself result education rest.”, “tags”: [{“value”: “Two draw somebody continue various travel speech training.”}], “properties”: {“additionalProperties”: “Maintain case fish politics instead professor door society.”}, “flags”: 948, “userACL”: [407], “createdByUser”: {“id”: 289, “customerID”: 792, “userName”: “lori69”, “name”: “John Ramsey”}, “status”: “CLOSED”, “logType”: “SECURITY_INCIDENT”, “customerReference”: “Likely thousand reduce also me ever cold.”, “priority”: 322, “contacts”: [{“id”: 912, “languageID”: 409, “name”: “Tracy Baldwin”, “value”: “Teacher more choose like.”, “flags”: 942, “subjectID”: 443, “verbose”: false, “language”: “ENGLISH”, “default”: false}], “id”: 709, “createdTimestamp”: 1361771582, “lastUpdatedTimestamp”: 378896353, “publishedTimestamp”: 1303652237}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Front blue interesting his environment owner.”, “messageTemplate”: “Per night animal star student catch set.”, “field”: “Well total red recent.”, “parameter”: {}, “timestamp”: 520168433}], “currentPage”: 47, “size”: 476}

## api.cases.v1.servicetypes module

Autogenerated API

`api.cases.v1.servicetypes.` `get`(json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List servicetypes (TEST)

  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 487, “limit”: 157, “responseCode”: 200, “count”: 749, “data”: [{“id”: 454, “name”: “Sierra Gomez”, “flags”: 850, “description”: “Own example her military bill foreign.”, “logoURL”: “Sit teacher fine much task forget suddenly.”, “notificationEmail”: “Activity commercial common population.”, “text”: “Class quality key fight nature perhaps reveal always.”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Clear rate who continue.”, “messageTemplate”: “Throw media his woman or sometimes mouth.”, “field”: “Stay question position sell today.”, “parameter”: {}, “timestamp”: 733455834}], “currentPage”: 129, “size”: 827}

`api.cases.v1.servicetypes.` `get_case`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch servicetype by ID (TEST)

  Return type: | `dict`
  Parameters: | id (int) – Servicetype ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 147, “limit”: 876, “responseCode”: 200, “count”: 187, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “School very television hit above though.”, “messageTemplate”: “Tree service gun partner possible.”, “field”: “Price soldier international affect theory stage still.”, “parameter”: {}, “timestamp”: 1515951318}], “currentPage”: 137, “size”: 357}

## Module contents